/*
================================================================================
(c)2004 David Sporn
================================================================================
Ce script est diffus selon les termes de la licence 
Creative-Common Attribution-Non Commercial 2.0
http://creativecommons.org/licenses/by-nc/2.0/
================================================================================
Texture d'talonnage

<h3>Objectif</h3>
<h3>La macro <code>setupMetricTextureKit</code></h3>
<p>Cette macro dfinit un certain nombre de textures permettant de se visualiser les dimensions
d'un objet. On considre qu'une unit quivaut  1 mtre.
</p>
<p>Si l'objet est dform, la texture sera aussi dforme, il faudra tenir compte de cet effet.
</p>

<h4>Paramtres</h4>
<dl>
<dt>baseTexture</dt>
<dd>Texture de base, par dessus laquelle on ajoute notre quadrillage.</dd>
<dt>backgroundColor</dt>
<dd>Couleur de fond, utilise pour le calcul de la couleur du quadrillage 0.1 et 0.2</dd>
<dt>rulerColor</dt>
<dd>Couleur du quadrillage, utilise pour le calcul de la couleur du quadrillage 1, 0.1 et 0.2</dd>
<dt>rulerWidth</dt>
<dd>Largeur du trait, en mm</dd>
</dl>

<h3>Image de test</h3>
<p><a href="/data/png/TestMetricTextures.png"><img src="/data/png/TestMetricTextures_mini.png" alt="Test des textures mtriques" lang="fr"/></a></p>
<h3>Tlchargement</h3>
L'archive (<a href="/data/zip/MetricTextures.zip">MetricTextures.zip</a>) contient tout le ncessaire pour gnrer l'image de test.

*/
#ifndef (SPORNIKET_METRIC_TEXTURE_INC)
#declare SPORNIKET_METRIC_TEXTURE_INC = 1 ;


//setup a base gradient along x axis
//ruleWidth must be insinde [0.001, 0.5]
#macro createRulePigment(ruleColor, ruleWidth)
	#local transparent_color = color transmit 1.0 ;
	#local rule_width = min(0.5 , max(0.001, ruleWidth)) ;
	#local first_limit = rule_width / 2 ;
	#local last_limit = 1 - first_limit ;
    pigment
    {
        gradient x
        color_map
        {
        	[0 color ruleColor]
        	[first_limit color ruleColor]
        	[first_limit color transparent_color]
        	[last_limit color transparent_color]
        	[last_limit color ruleColor]
        	[1 color ruleColor]
        }
    }
#end

//setup a ruler along the x axis
#macro setupMetricTexture(rulerColor, rulerScale, rulerWidth)
	#local bg_color = backgroundColor ;
	#local rule_width = rulerWidth / rulerScale / 1000 ;
	
	createRulePigment(rulerColor, rule_width)
	scale <rulerScale, 1, 1>
	finish
	{
		ambient 1.0
	}
#end

//create metric texture declaration
#macro setupMetricTextureKit(baseTexture, backgroundColor, rulerColor, rulerWidth)
	#local meter_color = rulerColor ;
	#local dodecimeter_color = rulerColor * .75 + backgroundColor * .25 ;
	#local decimeter_color = rulerColor * .5 + backgroundColor * .5 ;
	
    #declare MeterTexture = texture
    {
        setupMetricTexture(meter_color, 1, rulerWidth)
    }
    #declare DodecimeterTexture = texture
    {
        setupMetricTexture(dodecimeter_color, 0.2, rulerWidth * 0.75)
    }
    #declare DecimeterTexture = texture
    {
        setupMetricTexture(decimeter_color, 0.1, rulerWidth * 0.5)
    }
    #declare MetricTextureX = 
    	texture { baseTexture }
    	texture { DecimeterTexture }
    	texture { DodecimeterTexture }
    	texture { MeterTexture }
    #declare MetricTextureZ = 
    	texture { baseTexture }
    	texture { DecimeterTexture rotate y*90 }
    	texture { DodecimeterTexture rotate y*90 }
    	texture { MeterTexture rotate y*90 }
    #declare MetricTextureY = 
    	texture { baseTexture }
    	texture { DecimeterTexture rotate z*90 }
    	texture { DodecimeterTexture rotate z*90 }
    	texture { MeterTexture rotate z*90 }
    #declare MetricTextureXZ = 
    	texture { baseTexture }
    	texture { DecimeterTexture }
    	texture { DecimeterTexture rotate y*90 }
    	texture { DodecimeterTexture }
    	texture { DodecimeterTexture rotate y*90 }
    	texture { MeterTexture }
    	texture { MeterTexture rotate y*90 }
    #declare MetricTextureXY = 
    	texture { baseTexture }
    	texture { DecimeterTexture }
    	texture { DecimeterTexture rotate z*90 }
    	texture { DodecimeterTexture }
    	texture { DodecimeterTexture rotate z*90 }
    	texture { MeterTexture }
    	texture { MeterTexture rotate z*90 }
    #declare MetricTextureYZ = 
    	texture { baseTexture }
    	texture { DecimeterTexture rotate y*90 }
    	texture { DecimeterTexture rotate z*90 }
    	texture { DodecimeterTexture rotate y*90 }
    	texture { DodecimeterTexture rotate z*90 }
    	texture { MeterTexture rotate y*90 }
    	texture { MeterTexture rotate z*90 }
    #declare MetricTextureXYZ = 
    	texture { baseTexture }
    	texture { DecimeterTexture }
    	texture { DecimeterTexture rotate y*90 }
    	texture { DecimeterTexture rotate z*90 }
    	texture { DodecimeterTexture }
    	texture { DodecimeterTexture rotate y*90 }
    	texture { DodecimeterTexture rotate z*90 }
    	texture { MeterTexture }
    	texture { MeterTexture rotate y*90 }
    	texture { MeterTexture rotate z*90 }
#end

//#ifndef SPORNIKET_METRIC_TEXTURE_INC
#end
