/*
================================================================================
(c)2004 David Sporn
================================================================================
Ce script est diffus selon les termes de la licence 
Creative-Common Attribution-Non Commercial 2.0
http://creativecommons.org/licenses/by-nc/2.0/
================================================================================
Rglage d'une camra "raliste"

<h3>Objectif</h3>
<p>On veut rgler les paramtres d'une camra pour simuler la gomtrie d'un vritable appareil photo ou d'une camra de cinma.
</p>

<h3>Rappel sur le modle suivi par la directive <code>camera</code></h3>
<p>Dans Povray, la directive <code>camera</code> dfinit une pyramide  base rectangulaire. Le sommet est l'origine
des rayons qui sont lancs, et le pixel rsultant pour le lanc d'un rayon est projet sur la base.
</p>

<h3>Mise en oeuvre</h3>
<p>Pour simuler un appareil photo ou une camra, on va dimensionner la pyramide pour correspondre
 la surface de la pellicule (pour la base de la pyramide). La hauteur de la pyramide correspondra  la distance
focale.
</p>

<h4>A noter</h4>
<p>Pour une largeur de 36mm, une distance focale d'environ 60mm reproduit la vision humaine. J'ai obtenu cette valeur en regardant
dans le viseur d'un appareil photo Reflex et en laissant le deuxime oeil  ouvert, jusqu' ce l'image dans le viseur aie le m&ecirc;me
aspect que pour l'oeil libre.
</p>

<h3>Paramtres</h3>
<dl>
<dt>focale</dt>
<dd>Distance en mm entre le centre optique et la "pellicule".</dd>
<dt>film</dt>
<dd>Largeur en mm de la "pellicule"</dd>
<dt>format</dt>
<dd>Rapport largeur/hauteur de la pellicule (p.ex. 16/9, 4/3, 3/2, etc...)</dd>
</dl>

<h3>Exemple d'utilisation</h3>
<pre>
#include "realcamera.inc"

//etc...

camera
{
    location  &lt;.6 , 1.7 ,.1&gt;
    setupRealCamera(60, 22, image_width/image_height)
    look_at   &lt;2 , 1.0 , 2.5&gt;
}
</pre>

<h3>Code Source</h3>
<pre>
//utiliser dans une camera, avant look_at
//focale : distance en mm du centre optique  la pellicule
//film : largeur en mm de la pellicule
//format : rapport largeur/hauteur de l'image (ex : 16/9, 4/3, 3/2)
#macro setupRealCamera(focale, film, format)
    #local myFocale = focale / 1000 ;
    #local myRight = film / 1000 ;
    #local myUp = myRight / format ;

    direction     myFocale        * z
    up            myUp            * y
    right         myRight         * x  
#end
</pre>
================================================================================
*/

#ifndef (SPORNIKET_REAL_CAMERA_INC)
#declare SPORNIKET_REAL_CAMERA_INC = 1 ;


	//utiliser dans une camera, avant look_at
	//focale : distance en mm du centre optique  la pellicule
	//film : largeur en mm de la pellicule
	//format : rapport largeur/hauteur de l'image (ex : 16/9, 4/3, 3/2)
	#macro setupRealCamera(focale, film, format)
	    #local myFocale = focale / 1000 ;
	    #local myRight = film / 1000 ;
	    #local myUp = myRight / format ;
	
	    direction     myFocale        * z
	    up            myUp            * y
	    right         myRight         * x  
	#end


#end